import caosdb as db

RETRIEVE = 0
INSERT = 1
UPDATE = 2


class Guard(object):

    def __init__(self, level=RETRIEVE):
        self.freshly_created = []
        self.level = level

    def safe_insert(self, obj, ):
        if self.level < INSERT:
            raise Exception("not allowed")
        obj.insert()

        if isinstance(obj, db.Container):
            self.freshly_created.extend([
                e.id for e in obj])
        else:
            self.freshly_created.append(obj.id)

    def safe_update(self, obj, **kwargs):
        if isinstance(obj, db.Container):
            all_fresh = True

            for el in obj:
                if el.id not in self.freshly_created:
                    all_fresh = False

            if self.level < UPDATE and not all_fresh:
                raise Exception("not allowed")
            else:
                obj.update(**kwargs)
        else:
            if self.level < UPDATE and obj.id not in self.freshly_created:
                raise Exception("not allowed")
            else:
                obj.update(**kwargs)

    def set_level(self, level):
        self.level = level


global_guard = Guard()
